@@ -38,12 +38,16 @@ class ClusteringOptimizer:
 		self._silhouette_scores = {}
 
 		def get_scores(k, num_jobs):
-			kmeans = KMeans(n_clusters=k, n_jobs=num_jobs, timeout=self._timeout, raise_timeout=raise_timeout, **self._kwargs)
+			kmeans = KMeans(
+				n_clusters=k, n_jobs=num_jobs, timeout=self._timeout, raise_timeout=raise_timeout, **self._kwargs
+			)
 			kmeans.fit(X=X)
 			if kmeans.timedout:
 				return k, None, None, None
+
 			if self._keep_models:
 				return k, kmeans, kmeans.inertia, kmeans.distortion, kmeans.silhouette_score
+
 			else:
 				return k, None, kmeans.inertia, kmeans.distortion, kmeans.silhouette_score
 
@@ -125,8 +129,10 @@ class ClusteringOptimizer:
 
 		if by.startswith('inertia'):
 			y_dictionary = self._inertias
+
 		elif by.startswith('distort'):
 			y_dictionary = self._distortions
+
 		else:
 			y_dictionary = None
 			ValueError(f'Method "{by}" is not supported!')
